@@ -4,6 +4,7 @@ import yaml
 import json
 import boto3
 import decimal
+import logging
 
 data_yaml_file = '/data.yml'
 
@@ -17,11 +18,15 @@ def get_data_yaml_dict(connection_type):
 
 
 def get_dynamo_table(access_key, secret_access_key, region, table):
+
+    logging.warning('connecting to dynamo from data utilities.....')
+
     return boto3.resource('dynamodb',
                           aws_access_key_id=access_key,
                           aws_secret_access_key=secret_access_key,
                           region_name=region,
-                          verify=False).Table(table)
+                          verify=False,
+                          use_ssl=False).Table(table)
 
 
 def replace_decimals(obj):
